#!/bin/bash

# GET SUDO privilege (Change sudo to gksu or gksudo if you prefer a graphical prompt)
echo "***********************************************"
echo "*           eDRUMin Control Setup             *"
echo "***********************************************"
echo
echo "This installer requires root privileges..."
[ "$UID" -eq 0 ] || exec sudo bash "$0" "$@"

APP_INSTALL_FOLDER="/opt/eDRUMin"
BINARY_NAME="eDRUMin"
VST3_NAME="edrumin.vst3"
SHORTCUT_NAME="eDRUMin.desktop"
USER_HOME=$(getent passwd $SUDO_USER | cut -d: -f6)
SHORTCUT_PATH="/usr/share/applications/${SHORTCUT_NAME}"
RULES_PATH="/etc/udev/rules.d/eDRUMin.rules"
PDF="eDRUMin.pdf"
ICON_NAME="icon.png"

ICON_PATH="${USER_HOME}/.AudioFront/eDRUMin/${ICON_NAME}"

#REMOVE OLD STUFF
if [ -d "${APP_INSTALL_FOLDER}" ]; then 
    echo "Uninstalling previous version..."
    rm -r "${APP_INSTALL_FOLDER}"
fi

#create application folder
mkdir "${APP_INSTALL_FOLDER}"

echo "Creating folder structure..."
#make firmware folder
mkdir "${APP_INSTALL_FOLDER}/firmware"
mkdir "${APP_INSTALL_FOLDER}/vst3"

#copy the binary
echo "Copying application binaries..."
cp "./bin/${BINARY_NAME}"  "${APP_INSTALL_FOLDER}"
cp -r "./bin/${VST3_NAME}" "${APP_INSTALL_FOLDER}/vst3/"

#copy the firmware
echo "Copying firmware..."
cp -r "./firmware" "${APP_INSTALL_FOLDER}/"


echo "Creating Desktop shortcut..."
echo "[Desktop Entry]" > "${SHORTCUT_PATH}"
echo "Type=Application" >> "${SHORTCUT_PATH}"
echo "Terminal=false" >> "${SHORTCUT_PATH}"
echo "Name=eDRUMin" >> "${SHORTCUT_PATH}"
echo "Icon=${ICON_PATH}" >> "${SHORTCUT_PATH}"
echo "Exec=${APP_INSTALL_FOLDER}/${BINARY_NAME}" >> "${SHORTCUT_PATH}"
echo "StartupNotify=true" >> "${SHORTCUT_PATH}"
echo "StartupWMClass=eDRUMin" >> "${SHORTCUT_PATH}"

chmod 755 "${SHORTCUT_PATH}"
chmod +x "${SHORTCUT_PATH}"


chmod -R 777 "${APP_INSTALL_FOLDER}/firmware"


echo "Adding udev rules..."

if test -f "$RULES_PATH"; then
    rm "${RULES_PATH}"
fi

touch ${RULES_PATH}

echo "# MIDI EXPRESSION rules to allow accessing to rawhid devices"  >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0460\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0461\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0462\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0463\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0464\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0465\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0478\", MODE:=\"0666\"" >> "${RULES_PATH}"

udevadm control --reload

if test -f "${USER_HOME}/.AudioFront/${PDF}"; then
    rm "${USER_HOME}/.AudioFront/${PDF}"
fi
cp "./${PDF}" "${USER_HOME}/.AudioFront/"
chmod 777 "${USER_HOME}/.AudioFront/${PDF}"

cp "./${ICON_NAME}" "${USER_HOME}/.AudioFront/eDRUMin"
chown $SUDO_USER "${USER_HOME}/.AudioFront/eDRUMin/${ICON_NAME}"
chown :$SUDO_USER "${USER_HOME}/.AudioFront/eDRUMin/${ICON_NAME}"

chmod 777 "${USER_HOME}/.AudioFront/eDRUMin/${ICON_NAME}"


echo "Installation complete."

